@@ -249,7 +249,7 @@ USERS = {
         'uid': 42467,
         'gid': 42467,
     },
-    'skydive-user': {
+    'skydive-user': {  # unused user (skydive dropped)
         'uid': 42468,
         'gid': 42468,
     },
@@ -334,8 +334,8 @@ USERS = {
         'uid': 42490,
         'gid': 42490,
     },
-    'opensearch-dashboards-user': {
-        'uid': 42492,
-        'gid': 42492,
+    'skyline-user': {
+        'uid': 42491,
+        'gid': 42491,
     }
 }
