@@ -16,10 +16,9 @@
 # must match for skip to happen.
 UNBUILDABLE_IMAGES = {
     'aarch64': {
-        "bifrost-base",        # someone need to get upstream working first
+        "bifrost-base",      # someone need to get upstream working first
         "prometheus-msteams",  # no aarch64 binary
-        "prometheus-mtail",    # no aarch64 binary
-        "skydive-base",        # no aarch64 binary
+        "prometheus-mtail",  # no aarch64 binary
     },
 
     # Issues for SHA1 keys:
@@ -42,6 +41,8 @@ UNBUILDABLE_IMAGES = {
     },
 
     'ubuntu': {
+        "collectd",              # Missing collectd-core package
+        "telegraf",              # Missing collectd-core package
     },
 
     'ubuntu+aarch64': {
@@ -49,6 +50,6 @@ UNBUILDABLE_IMAGES = {
     },
 
     'centos+aarch64': {
-        "telegraf",      # no binary package
+        "telegraf",       # no binary package
     },
 }
